@@ -529,7 +529,7 @@ class StaticWebsiteProps:
         :stability: experimental
         '''
         if isinstance(distribution_props, dict):
-            distribution_props = DistributionProps(**distribution_props)
+            distribution_props = aws_cdk.aws_cloudfront.DistributionProps(**distribution_props)
         if isinstance(runtime_options, dict):
             runtime_options = RuntimeOptions(**runtime_options)
         if isinstance(web_acl_props, dict):
